==> boost_1_89_0.tar.lz: boost_1_89_0/libs/locale/doc/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Boost.Locale", "index.html", [
    [ "What is Boost.Locale?", "index.html#main_intro", null ],
    [ "Tutorials", "index.html#main_tutorial", null ],
    [ "Introduction to C++ Standard Library localization support", "std_locales.html", [
      [ "Getting familiar with standard C++ Locales", "std_locales.html#std_locales_basics", null ],
      [ "Common Critical Problems with the Standard Library", "std_locales.html#std_locales_common", null ]
    ] ],
    [ "Using Boost.Locale", "using_boost_locale.html", "using_boost_locale" ],
    [ "Using Localization Backends", "using_localization_backends.html", [
      [ "When to use non-ICU backends", "using_localization_backends.html#when_to_use_non_icu_backends", null ],
      [ "Non-ICU Backends", "using_localization_backends.html#non_icu_backends", [
        [ "std - The standard C++ library backend", "using_localization_backends.html#std_backend", null ],
        [ "posix - POSIX 2008 C library", "using_localization_backends.html#posix_backend", null ],
        [ "winapi - Win32 API.", "using_localization_backends.html#winapi_backend", null ]
      ] ],
      [ "Supported Features", "using_localization_backends.html#supported_features_by_backends", null ],
      [ "Using Localization Backends", "using_localization_backends.html#using_localization_backends_sec", null ]
    ] ],
    [ "Recommendations and Myths", "recommendations_and_myths.html", [
      [ "Recommendations", "recommendations_and_myths.html#recommendations", null ],
      [ "Myths", "recommendations_and_myths.html#myths", [
        [ "To use Unicode in my application I should use wide strings everywhere.", "recommendations_and_myths.html#myths_wide", null ],
        [ "UTF-16 is the best encoding to work with.", "recommendations_and_myths.html#myths_utf16", null ]
      ] ]
    ] ],
    [ "Building the Library", "building_boost_locale.html", [
      [ "Building Boost.Locale", "building_boost_locale.html#building_boost_locale_bb", [
        [ "Dependencies", "building_boost_locale.html#bb_building_deps", null ],
        [ "Platform Notes", "building_boost_locale.html#bb_platform_opts", null ],
        [ "Building Process", "building_boost_locale.html#bb_building_proc", null ]
      ] ],
      [ "Build Options", "building_boost_locale.html#bb_build_opts", null ],
      [ "Running Unit Tests", "building_boost_locale.html#bb_build_test", null ],
      [ "Binary Compatibility", "building_boost_locale.html#binary_compatibility", null ]
    ] ],
    [ "Appendix", "appendix.html", "appendix" ],
    [ "Changelog", "changelog.html", null ],
    [ "Topics", "topics.html", "topics" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ]
    ] ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"allocator__traits_8hpp_source.html",
"classboost_1_1locale_1_1date__time.html#a8d00584d1f1b2dc0f9b44ef53e2a15e9",
"classboost_1_1locale_1_1util_1_1base__converter.html#a77f96b74594000cacbbfa8e05817e2af",
"group__boundary.html#gae65acde77977cbb3961aaf8486dd63e6",
"namespaceboost_1_1locale_1_1flags.html#ab0255a81e609e12040ca07dda4434a99ad1d78f10bf2abf74da44c0b29b00d422",
"structboost_1_1locale_1_1gnu__gettext_1_1messages__info.html#a4a7406581c6c7975c90db9d2d157d384"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> boost_1_90_0.tar.lz: boost_1_90_0/libs/locale/doc/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Boost.Locale", "index.html", [
    [ "What is Boost.Locale?", "index.html#main_intro", null ],
    [ "Tutorials", "index.html#main_tutorial", null ],
    [ "Introduction to C++ Standard Library localization support", "std_locales.html", [
      [ "Getting familiar with standard C++ Locales", "std_locales.html#std_locales_basics", null ],
      [ "Common Critical Problems with the Standard Library", "std_locales.html#std_locales_common", null ]
    ] ],
    [ "Using Boost.Locale", "using_boost_locale.html", "using_boost_locale" ],
    [ "Using Localization Backends", "using_localization_backends.html", [
      [ "When to use non-ICU backends", "using_localization_backends.html#when_to_use_non_icu_backends", null ],
      [ "Non-ICU Backends", "using_localization_backends.html#non_icu_backends", [
        [ "std - The standard C++ library backend", "using_localization_backends.html#std_backend", null ],
        [ "posix - POSIX 2008 C library", "using_localization_backends.html#posix_backend", null ],
        [ "winapi - Win32 API.", "using_localization_backends.html#winapi_backend", null ]
      ] ],
      [ "Supported Features", "using_localization_backends.html#supported_features_by_backends", null ],
      [ "Using Localization Backends", "using_localization_backends.html#using_localization_backends_sec", null ]
    ] ],
    [ "Recommendations and Myths", "recommendations_and_myths.html", [
      [ "Recommendations", "recommendations_and_myths.html#recommendations", null ],
      [ "Myths", "recommendations_and_myths.html#myths", [
        [ "To use Unicode in my application I should use wide strings everywhere.", "recommendations_and_myths.html#myths_wide", null ],
        [ "UTF-16 is the best encoding to work with.", "recommendations_and_myths.html#myths_utf16", null ]
      ] ]
    ] ],
    [ "Building the Library", "building_boost_locale.html", [
      [ "Building Boost.Locale", "building_boost_locale.html#building_boost_locale_bb", [
        [ "Dependencies", "building_boost_locale.html#bb_building_deps", null ],
        [ "Platform Notes", "building_boost_locale.html#bb_platform_opts", null ],
        [ "Building Process", "building_boost_locale.html#bb_building_proc", null ]
      ] ],
      [ "Build Options", "building_boost_locale.html#bb_build_opts", null ],
      [ "Running Unit Tests", "building_boost_locale.html#bb_build_test", null ],
      [ "Binary Compatibility", "building_boost_locale.html#binary_compatibility", null ]
    ] ],
    [ "Appendix", "appendix.html", "appendix" ],
    [ "Changelog", "changelog.html", null ],
    [ "Topics", "topics.html", "topics" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ]
    ] ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"allocator__traits_8hpp_source.html",
"classboost_1_1locale_1_1date__time.html#a8d00584d1f1b2dc0f9b44ef53e2a15e9",
"classboost_1_1locale_1_1util_1_1base__converter.html#a77f96b74594000cacbbfa8e05817e2af",
"group__boundary.html#gae4ac52a6957bbe887f909a3a4827799e",
"namespaceboost_1_1locale_1_1flags.html#ab0255a81e609e12040ca07dda4434a99ad1d78f10bf2abf74da44c0b29b00d422",
"structboost_1_1locale_1_1gnu__gettext_1_1messages__info_1_1domain.html#a3f652fb5ab683b83ca1977e83a0a7e1d"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
var LISTOFALLMEMBERS = 'List of all members';
